@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-__version__ = '1.0.0'
+__version__ = '1.1.0'
 
 try:
     # Fix for setup.py version import
     from watson.form.types import Form, Multipart
 
     __all__ = ['Form', 'Multipart']
-except:
-    pass
+except:  # pragma: no cover
+    pass  # pragma: no cover
